@@ -82,7 +82,7 @@ sub validate_options {
     my $form = HTML::FormFu::ExtJS->new;
     $form->populate($self->_extjs_config->{list_options_validation});
     if(-e $self->list_options_file) {
-        $c->log->debug('found configuration file for parameters');
+        $c->log->debug('found configuration file for parameters') if($c->debug);
         $form->load_config_file($self->list_options_file);
     }
     $form->process($c->req->params);
@@ -164,6 +164,11 @@ sub paging_rs : Private {
     return $paged;
 }
 
+sub base : Chained('/') NSPathPart CaptureArgs(1) {
+    my ( $self, $c, $id ) = @_;
+    $self->object($c, $id);
+}
+
 sub object : Chained('/') NSPathPart Args ActionClass('REST') {
     my ( $self, $c, $id ) = @_;
 
@@ -406,6 +411,10 @@ __END__
 
 CatalystX::Controller::ExtJS::REST - RESTful interface to dbic objects
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   package MyApp::Controller::User;
@@ -795,4 +804,4 @@ This is free software, licensed under:
 
   The (three-clause) BSD License
 
-=cut
+=cut
\ No newline at end of file
